==> aliyun-python-sdk-sas-1.1.20.tar.gz: aliyun-python-sdk-sas-1.1.20/aliyunsdksas/request/v20181203/DescribeOnceTaskRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class DescribeOnceTaskRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeOnceTask')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_RootTaskId(self): # String
		return self.get_query_params().get('RootTaskId')

	def set_RootTaskId(self, RootTaskId):  # String
		self.add_query_param('RootTaskId', RootTaskId)
	def get_EndTimeQuery(self): # Long
		return self.get_query_params().get('EndTimeQuery')

	def set_EndTimeQuery(self, EndTimeQuery):  # Long
		self.add_query_param('EndTimeQuery', EndTimeQuery)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_TaskType(self): # String
		return self.get_query_params().get('TaskType')

	def set_TaskType(self, TaskType):  # String
		self.add_query_param('TaskType', TaskType)
	def get_StartTimeQuery(self): # Long
		return self.get_query_params().get('StartTimeQuery')

	def set_StartTimeQuery(self, StartTimeQuery):  # Long
		self.add_query_param('StartTimeQuery', StartTimeQuery)
	def get_CurrentPage(self): # Integer
		return self.get_query_params().get('CurrentPage')

	def set_CurrentPage(self, CurrentPage):  # Integer
		self.add_query_param('CurrentPage', CurrentPage)

==> aliyun-python-sdk-sas-2.0.0.tar.gz: aliyun-python-sdk-sas-2.0.0/aliyunsdksas/request/v20181203/DescribeOnceTaskRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class DescribeOnceTaskRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeOnceTask')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_RootTaskId(self): # String
		return self.get_query_params().get('RootTaskId')

	def set_RootTaskId(self, RootTaskId):  # String
		self.add_query_param('RootTaskId', RootTaskId)
	def get_EndTimeQuery(self): # Long
		return self.get_query_params().get('EndTimeQuery')

	def set_EndTimeQuery(self, EndTimeQuery):  # Long
		self.add_query_param('EndTimeQuery', EndTimeQuery)
	def get_PageSize(self): # Integer
		return self.get_query_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_query_param('PageSize', PageSize)
	def get_TaskId(self): # String
		return self.get_query_params().get('TaskId')

	def set_TaskId(self, TaskId):  # String
		self.add_query_param('TaskId', TaskId)
	def get_TaskType(self): # String
		return self.get_query_params().get('TaskType')

	def set_TaskType(self, TaskType):  # String
		self.add_query_param('TaskType', TaskType)
	def get_StartTimeQuery(self): # Long
		return self.get_query_params().get('StartTimeQuery')

	def set_StartTimeQuery(self, StartTimeQuery):  # Long
		self.add_query_param('StartTimeQuery', StartTimeQuery)
	def get_CurrentPage(self): # Integer
		return self.get_query_params().get('CurrentPage')

	def set_CurrentPage(self, CurrentPage):  # Integer
		self.add_query_param('CurrentPage', CurrentPage)
